@@ -3,7 +3,7 @@ use Moose;
 
 use MooseX::Iterator::Meta::Iterable;
 
-our $VERSION   = '0.09';
+our $VERSION   = '0.10';
 our $AUTHORITY = 'cpan:RLB';
 
 with 'MooseX::Iterator::Role';
@@ -33,6 +33,11 @@ sub peek {
     return;
 }
 
+sub reset {
+    my ($self) = @_;
+    $self->_position(0);
+}
+
 no Moose;
 
 1;
